==> haskell-either-5.0.2-123-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 either
version:              5.0.2
visibility:           public
id:                   either-5.0.2-8TDpOlEdMrNAUbgXy6cVg7
key:                  either-5.0.2-8TDpOlEdMrNAUbgXy6cVg7
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/either/
synopsis:             Combinators for working with sums
description:          Combinators for working with sums.
category:             Control, Monads
abi:                  fae6c79b463f46aefec05f6b9d692916
exposed:              True
exposed-modules:      Data.Either.Combinators Data.Either.Validation
import-dirs:          /usr/lib/ghc-9.2.8/site-local/either-5.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/either-5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-either
hs-libraries:         HSeither-5.0.2-8TDpOlEdMrNAUbgXy6cVg7
depends:
    base-4.16.4.0 bifunctors-5.6-9rru5OtNSdB2ahpJRfMRFz mtl-2.2.2
    profunctors-5.6.2-5OpgspEUbplLWaTkoK7BoP
    semigroupoids-5.3.7-6de0LhpTIq5Evno33LzoOj

haddock-interfaces:   /usr/share/doc/haskell-either/html/either.haddock
haddock-html:         /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-either-5.0.2-124-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 either
version:              5.0.2
visibility:           public
id:                   either-5.0.2-CSU4bgmaXq48Xduz2iMOrt
key:                  either-5.0.2-CSU4bgmaXq48Xduz2iMOrt
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/either/
synopsis:             Combinators for working with sums
description:          Combinators for working with sums.
category:             Control, Monads
abi:                  fafaf524894ab1d8a0a8e06d954fe46d
exposed:              True
exposed-modules:      Data.Either.Combinators Data.Either.Validation
import-dirs:          /usr/lib/ghc-9.2.8/site-local/either-5.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/either-5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-either
hs-libraries:         HSeither-5.0.2-CSU4bgmaXq48Xduz2iMOrt
depends:
    base-4.16.4.0 bifunctors-5.6-CrUyzQPkpNK3ytokiaNs5F mtl-2.2.2
    profunctors-5.6.2-7EvXszvdoMRIenez5xMjgl
    semigroupoids-5.3.7-2Bbz5Qu2PBmJORnT4d1pIg

haddock-interfaces:   /usr/share/doc/haskell-either/html/either.haddock
haddock-html:         /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
